@@ -4,8 +4,8 @@ from django.contrib import admin
 
 
 class CloudStackPackAdmin(admin.ModelAdmin):
-    search_fields = ("offering", "engine_type", )
-    list_display = ("pack_offering","pack_region", "is_ha", "engine_type")
+    search_fields = ("pack_offering", "engine_type", )
+    list_display = ("pack_offering","pack_region","pack_environment", "is_ha", "engine_type")
     save_on_top = True
 
     def pack_region(self, pack):
